@@ -1,4 +1,4 @@
-// kdelibs4.js of Ukrainian KDE translation (copied from Serbian)
+// kdelibs4.js of Ukrainian KDE translation
 
 // ------------------------------
 // Pick a phrase depending on a dynamic context field.
@@ -36,3 +36,15 @@ function select_by_context (/* ctxt_key,
     return phrase;
 }
 Ts.setcall("за-контекстом", select_by_context);
+
+// Return the phrase without the given prefix if it has it,
+// or the full phrase otherwise.
+// Thanks to Chusslove Ilich from Serbian team
+function without_prefix (prefix, phrase)
+{
+    if (phrase.indexOf(prefix) == 0) {
+        phrase = phrase.substr(prefix.length);
+    }
+    return phrase;
+}
+  Ts.setcall("без-префікса", without_prefix);
\ No newline at end of file
